pub struct Reconstructed {
pub hash: Hash,
pub bytes: Vec<u8>,
pub object: Object,
pub extras: Vec<(Hash, Vec<u8>)>,
}Expand description
A reconstructed mkit object: its serialized v1 bytes and BLAKE3
hash. extras carries the chunk blobs a large flattened blob
re-chunks into (empty for everything else).
Fields
hash: Hashbytes: Vec<u8>object: Objectextras: Vec<(Hash, Vec<u8>)>Trait Implementations
Sourceimpl Clone for Reconstructed
impl Clone for Reconstructed
Sourcefn clone(&self) -> Reconstructed
fn clone(&self) -> Reconstructed
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Reconstructed
impl Debug for Reconstructed
impl Eq for Reconstructed
Sourceimpl PartialEq for Reconstructed
impl PartialEq for Reconstructed
Sourcefn eq(&self, other: &Reconstructed) -> bool
fn eq(&self, other: &Reconstructed) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Reconstructed